==> kubernetes-model-1.0.56-sources.jar: io/fabric8/kubernetes/api/model/RBDVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.String;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.util.List;
import javax.validation.Valid;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.fabric8.kubernetes.api.builder.Nested;

public interface RBDVolumeSourceFluent<A extends RBDVolumeSourceFluent<A>> extends Fluent<A>{


    public String getFsType();
    public A withFsType(String fsType);
    public String getImage();
    public A withImage(String image);
    public String getKeyring();
    public A withKeyring(String keyring);
    public A addToMonitors(String... items);
    public A removeFromMonitors(String... items);
    public List<String> getMonitors();
    public A withMonitors(List<String> monitors);
    public A withMonitors(String... monitors);
    public String getPool();
    public A withPool(String pool);
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public LocalObjectReference getSecretRef();
    public A withSecretRef(LocalObjectReference secretRef);
    public RBDVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public RBDVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(LocalObjectReference item);
    public RBDVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public A withNewSecretRef(String name);
    public String getUser();
    public A withUser(String user);

    public interface SecretRefNested<N> extends Nested<N>,LocalObjectReferenceFluent<RBDVolumeSourceFluent.SecretRefNested<N>>{

        
    public N endSecretRef();    public N and();
}


}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/kubernetes/api/model/RBDVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import javax.annotation.Generated;
import io.fabric8.kubernetes.api.builder.Fluent;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.String;
import javax.validation.Valid;
import java.lang.Object;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import java.util.Map;
import io.sundr.builder.annotations.Buildable;

public interface RBDVolumeSourceFluent<A extends RBDVolumeSourceFluent<A>> extends Fluent<A>{


    public String getFsType();
    public A withFsType(String fsType);
    public String getImage();
    public A withImage(String image);
    public String getKeyring();
    public A withKeyring(String keyring);
    public A addToMonitors(String... items);
    public A removeFromMonitors(String... items);
    public List<String> getMonitors();
    public A withMonitors(List<String> monitors);
    public A withMonitors(String... monitors);
    public String getPool();
    public A withPool(String pool);
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public LocalObjectReference getSecretRef();
    public A withSecretRef(LocalObjectReference secretRef);
    public RBDVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public RBDVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(LocalObjectReference item);
    public RBDVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public RBDVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public RBDVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(LocalObjectReference item);
    public A withNewSecretRef(String name);
    public String getUser();
    public A withUser(String user);

    public interface SecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LocalObjectReferenceFluent<RBDVolumeSourceFluent.SecretRefNested<N>>{

        
    public N and();    public N endSecretRef();
}


}
